@@ -1,8 +1,10 @@
 #!/usr/bin/env python
 # -*- encoding:utf-8 -*-
 
-__version__ = "0.3.0"
+from .gamess import Gamess, GamessError
+
+__version__ = "0.5.0"
 __all__ = ["Gamess"]
 
-from gamess import Gamess, GamessError
+
 del(gamess)
